summaryrefslogtreecommitdiff
path: root/src/backend/taler-merchant-httpd_auditors.c
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2016-03-01 16:16:36 +0100
committerChristian Grothoff <christian@grothoff.org>2016-03-01 16:16:36 +0100
commit94059c0329921b422b1c7f27d946b0f550fe7978 (patch)
treecd4adc78a6d0687b5b6f12512184a9db1cc2d5aa /src/backend/taler-merchant-httpd_auditors.c
parent281d39c6afbd4133ab1f13acd0915276f45a9b57 (diff)
downloadmerchant-94059c0329921b422b1c7f27d946b0f550fe7978.tar.gz
merchant-94059c0329921b422b1c7f27d946b0f550fe7978.tar.bz2
merchant-94059c0329921b422b1c7f27d946b0f550fe7978.zip
mint->exchange renaming
Diffstat (limited to 'src/backend/taler-merchant-httpd_auditors.c')
-rw-r--r--src/backend/taler-merchant-httpd_auditors.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/backend/taler-merchant-httpd_auditors.c b/src/backend/taler-merchant-httpd_auditors.c
index 7caa40ea..e479f8b6 100644
--- a/src/backend/taler-merchant-httpd_auditors.c
+++ b/src/backend/taler-merchant-httpd_auditors.c
@@ -15,7 +15,7 @@
*/
/**
* @file backend/taler-merchant-httpd_auditors.c
* @brief logic this HTTPD keeps for each mint we interact with
* @author Marcello Stanisci
* @author Christian Grothoff
*/
@@ -56,28 +56,28 @@ static struct Auditor *auditors;
static unsigned int nauditors;
/**
* JSON representation of the auditors accepted by this mint.
*/
json_t *j_auditors;
/**
* Check if the given @a dk issued by mint @a mh is audited by
* an auditor that is acceptable for this merchant. (And if the
* denomination is not yet expired or something silly like that.)
*
* @param mh mint issuing @a dk
* @param dk a denomination issued by @a mh
* @param mint_trusted #GNUNET_YES if the mint of @a dk is trusted by config
* @return #GNUNET_OK if we accept this denomination
*/
int
-TMH_AUDITORS_check_dk (struct TALER_MINT_Handle *mh,
- const struct TALER_MINT_DenomPublicKey *dk,
- int mint_trusted)
+TMH_AUDITORS_check_dk (struct TALER_EXCHANGE_Handle *mh,
+ const struct TALER_EXCHANGE_DenomPublicKey *dk,
+ int exchange_trusted)
{
- const struct TALER_MINT_Keys *keys;
- const struct TALER_MINT_AuditorInformation *ai;
+ const struct TALER_EXCHANGE_Keys *keys;
+ const struct TALER_EXCHANGE_AuditorInformation *ai;
unsigned int i;
unsigned int j;
@@ -87,9 +87,9 @@ TMH_AUDITORS_check_dk (struct TALER_MINT_Handle *mh,
"Denomination key offered by client has expired for deposits\n");
return GNUNET_SYSERR; /* expired */
}
- if (GNUNET_YES == mint_trusted)
+ if (GNUNET_YES == exchange_trusted)
return GNUNET_OK;
- keys = TALER_MINT_get_keys (mh);
+ keys = TALER_EXCHANGE_get_keys (mh);
if (NULL == keys)
{
/* this should never happen, keys should have been successfully
@@ -203,7 +203,7 @@ TMH_AUDITORS_init (const struct GNUNET_CONFIGURATION_Handle *cfg)
&parse_auditors,
(void *) cfg);
/* Generate preferred mint(s) array. */
j_auditors = json_array ();
for (cnt = 0; cnt < nauditors; cnt++)
json_array_append_new (j_auditors,
@@ -15,7 +15,7 @@
/**
* @file backend/taler-merchant-httpd_auditors.c
- * @brief logic this HTTPD keeps for each mint we interact with
+ * @brief logic this HTTPD keeps for each exchange we interact with
* @author Marcello Stanisci
* @author Christian Grothoff
@@ -56,28 +56,28 @@ static struct Auditor *auditors;
static unsigned int nauditors;
/**
- * JSON representation of the auditors accepted by this mint.
+ * JSON representation of the auditors accepted by this exchange.
*/
json_t *j_auditors;
@@ -56,28 +56,28 @@ static struct Auditor *auditors;
json_t *j_auditors;
/**
- * Check if the given @a dk issued by mint @a mh is audited by
+ * Check if the given @a dk issued by exchange @a mh is audited by
* an auditor that is acceptable for this merchant. (And if the
* denomination is not yet expired or something silly like that.)
@@ -56,28 +56,28 @@ static struct Auditor *auditors;
* denomination is not yet expired or something silly like that.)
*
- * @param mh mint issuing @a dk
+ * @param mh exchange issuing @a dk
* @param dk a denomination issued by @a mh
@@ -56,28 +56,28 @@ static struct Auditor *auditors;
* @param dk a denomination issued by @a mh
- * @param mint_trusted #GNUNET_YES if the mint of @a dk is trusted by config
+ * @param exchange_trusted #GNUNET_YES if the exchange of @a dk is trusted by config
* @return #GNUNET_OK if we accept this denomination
*/
@@ -203,7 +203,7 @@ TMH_AUDITORS_init (const struct GNUNET_CONFIGURATION_Handle *cfg)
&parse_auditors,
(void *) cfg);
- /* Generate preferred mint(s) array. */
+ /* Generate preferred exchange(s) array. */
j_auditors = json_array ();
for (cnt = 0; cnt < nauditors; cnt++)